<?php
namespace Setka\Editor\Admin\Notices;

use Korobochkin\WPKit\Notices\Notice;
use Setka\Editor\Admin\Service\Screen;
use Setka\Editor\Plugin;
use Setka\Editor\Service\SetkaAccount\SetkaEditorAccount;

class InvitationToRegisterNotice extends Notice
{
    /**
     * @var SetkaEditorAccount
     */
    private $setkaEditorAccount;

    /**
     * @var string
     */
    private $signUpPageUrl;

    /**
     * @var Screen
     */
    private $screen;

    public function __construct(SetkaEditorAccount $setkaEditorAccount, string $signUpPageUrl, Screen $screen)
    {
        $this->setName(Plugin::NAME . '_invitation_to_register');

        $this->setkaEditorAccount = $setkaEditorAccount;
        $this->signUpPageUrl      = $signUpPageUrl;
        $this->screen             = $screen;
    }

    /**
     * @inheritdoc
     */
    public function lateConstruct(): self
    {
        $this
            ->setView(new NoticeSuccessView())
            ->getView()->setCssClasses(array_merge(
                $this->getView()->getCssClasses(),
                array('setka-editor-notice', 'setka-editor-notice-success')
            ));

        $content = sprintf(
            /* translators: Notice message in notice showed after plugin activation. %1$s - plugin settings page where you can create a new account. */
            __('<a href="%1$s" target="_blank">Register a Setka Editor account</a> to create your own post style with branded fonts, colors and other visual elements and customized grid system.', Plugin::NAME),
            esc_url($this->signUpPageUrl)
        );

        $this->setContent('<p>' . $content . '</p>');

        return $this;
    }

    /**
     * @inheritdoc
     */
    public function isRelevant(): bool
    {
        if (!current_user_can('manage_options')) {
            return false;
        }

        if ($this->setkaEditorAccount->isLoggedIn()) {
            return false;
        }

        return 'post' === $this->screen->getId() && 'add' === $this->screen->getAction();
    }
}
