<?php
namespace Setka\Editor\Admin\Notices;

use Korobochkin\WPKit\Notices\Notice;
use Setka\Editor\Admin\Service\Screen;
use Setka\Editor\Plugin;
use Setka\Editor\Service\SetkaAccount\SetkaEditorAccount;

class YouCanRegisterNotice extends Notice
{
    /**
     * @var SetkaEditorAccount
     */
    private $setkaEditorAccount;

    /**
     * @var Screen
     */
    private $screen;

    public function __construct(SetkaEditorAccount $setkaEditorAccount, Screen $screen)
    {
        $this->setName(Plugin::NAME . '_you_can_register');

        $this->setkaEditorAccount = $setkaEditorAccount;
        $this->screen             = $screen;
    }

    /**
     * @inheritdoc
     */
    public function lateConstruct(): self
    {
        $this
            ->setView(new NoticeSuccessView())
            ->getView()->setCssClasses(array_merge(
                $this->getView()->getCssClasses(),
                array('setka-editor-notice', 'setka-editor-notice-success')
            ));

        $content = __('Create posts with limited functionality in Setka Editor right now — no registration required. Register for a free Setka Editor account to modify your post styles.', Plugin::NAME);

        $this->setContent('<p>' . $content . '</p>');

        return $this;
    }

    /**
     * @inheritdoc
     */
    public function isRelevant(): bool
    {
        if ($this->setkaEditorAccount->isLoggedIn()) {
            return false;
        }

        if (Plugin::NAME === $this->screen->getParentBase()) {
            return true;
        }

        return false;
    }
}
