<?php
namespace Setka\Editor\Service\SystemReport;

use Korobochkin\WPKit\Plugins\PluginInterface;
use Setka\Editor\Admin\Service\FilesManager\AssetsStatus;
use Setka\Editor\Service\AMP\AMPStatus;
use Setka\Editor\Service\Standalone\StandaloneStatus;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBag;
use Symfony\Component\HttpFoundation\Request;

class SystemReportFactory
{
    /**
     * @var array
     */
    private static $converters = array(
        VarExportTypeConverter::class,
        PrintTypeConverter::class,
    );

    /**
     * @param PluginInterface $plugin
     * @param AMPStatus $AMPStatus
     * @param StandaloneStatus $standaloneStatus
     * @param AssetsStatus $assetsStatus
     * @param ParameterBag $parameterBag
     * @param Request $request
     *
     * @return SystemReport
     */
    public static function create(
        PluginInterface $plugin,
        AMPStatus $AMPStatus,
        StandaloneStatus $standaloneStatus,
        AssetsStatus $assetsStatus,
        ParameterBag $parameterBag,
        Request $request
    ) {
        return new SystemReport(
            array(
                new PluginSection($plugin),
                new CurrentUserSection(),
                new AMPStatisticsSection($AMPStatus),
                new StandaloneStatisticsSection($standaloneStatus),
                new AssetsStatisticsSection($assetsStatus),
                new FilesystemSection(),
                new OptionsSection(),
                new ParameterBagSection($parameterBag),
                new HooksAndFiltersSection(),
                new GlobalVariablesSection(),
                new ServerSuperGlobalSection($request),
                new PHPConstantsSection(),
                new IniSection(),
                new PHPInfoSection(),
            ),
            self::createConverter()
        );
    }

    /**
     * @return TypeConverterInterface
     */
    private static function createConverter()
    {
        foreach (self::$converters as $converter) {
            try {
                self::checkConvertMethods($converter);
                return new $converter();
            } catch (\Exception $exception) {
                return new EmptyTypeConverter();
            }
        }
    }

    /**
     * @param TypeConverterInterface $converter
     *
     * @throws \Exception
     */
    private static function checkConvertMethods($converter)
    {
        foreach ($converter::$methods as $method) {
            if (!function_exists($method)) {
                throw new \Exception();
            }
        }
    }
}
